#include "sql.hpp"

#include <cstdio>
#include <cstdlib>

#include <sqlite3.h>

void sql::init()
{
  sqlite3_initialize();
  sqlite3 *db;
  char *zErrMsg = 0;
  int rc;

  /* Open database */
  rc = sqlite3_open(DB_NAME, &db);

  if (rc)
  {
    fprintf(stderr, "Can't open database: %s\n", sqlite3_errmsg(db));
    return;
  }
  else
  {
    fprintf(stdout, "Opened database successfully\n");
  }

  /* Execute SQL statement */
  rc = sqlite3_exec(db, create_table, nullptr, 0, &zErrMsg);

  if (rc != SQLITE_OK)
  {
    fprintf(stderr, "SQL error: %s\n", zErrMsg);
    sqlite3_free(zErrMsg);
  }
  else
  {
    fprintf(stdout, "Table created successfully\n");
  }

  /* Execute SQL statement */
  rc = sqlite3_exec(db, create_index, nullptr, 0, &zErrMsg);

  if (rc != SQLITE_OK)
  {
    fprintf(stderr, "SQL error: %s\n", zErrMsg);
    sqlite3_free(zErrMsg);
  }
  else
  {
    fprintf(stdout, "Index created successfully\n");
  }

  sqlite3_close(db);
}

void sql::shutdown()
{
  sqlite3_shutdown();
}